using System;
using System.Collections.Generic;
using System.Text;
using Pageflex.Scripting;

public class DocActionsFitImage
{
    static public void setImagesResize()
    {
        Image[] images = Application.CurrentDocument.Images;
        // Application.Log(images.Length + " images");
        foreach (Image img in images)
        {
            // only proceed if the image is inside an area template
            if (img.Source != "" && img.Visible && img.ParentElement is AreaTemplate &&
                ((AreaTemplate)(img.ParentElement)).Name.ToLower() != "exempt") // ignore area templates whose name is "exempt"
            {
                // Application.Log(img.Source);
                resizeImage(img);
            }
        }
    }

    static private void resizeImage(Image image_child)
    {

        /* We don't want to scale and crop locked images,
         * so we set a check of the element to se if manipulation
         * is allowed. If allowed the script start running and if not
         * it just jump over the complete routine as it should
         */
        if (image_child.ConstrainSelectionAndEditing)
            return;

        Shape frame = (Shape)image_child.ParentElement;
        Measurement frameWidth = frame.Width;
        Measurement frameHeight = frame.Height;

        Measurement cWidth = image_child.Width;
        Measurement cHeight = image_child.Height;

        double hRatio = frameHeight / cHeight;
        double wRatio = frameWidth / cWidth;
        Application.Log("hratio: " + hRatio + "  wratio: " + wRatio);

        if (hRatio > wRatio)
        {
            Measurement newHeight = cHeight * hRatio;
            Measurement newWidth = (cWidth / cHeight) * newHeight;

            image_child.Height = newHeight;
            image_child.Width = newWidth;
        }
        else
        {
            Measurement newWidth = cWidth * wRatio;
            Measurement newHeight = (cHeight / cWidth) * newWidth;
            image_child.Width = newWidth;
            image_child.Height = newHeight;
        }

        cWidth = image_child.Width;
        cHeight = image_child.Height;

        Measurement zero = new Measurement(0, Measurement.Units.Mm);

        image_child.X = zero - (cWidth - frameWidth) / 2;
        image_child.Y = zero - (cHeight - frameHeight) / 2;

    }
}


